==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/EaseOfMovementIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { EaseOfMovementIndicatorStrategy } from "./EaseOfMovementIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var EaseOfMovementIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EaseOfMovementIndicator, _super);
    function EaseOfMovementIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EaseOfMovementIndicator.prototype.bg = function () {
        return new EaseOfMovementIndicator();
    };
    EaseOfMovementIndicator.prototype.get_yz = function () {
        return new EaseOfMovementIndicatorStrategy();
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.prototype.get_zc = function () {
        return EaseOfMovementIndicator.$;
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.$t = markType(EaseOfMovementIndicator, 'EaseOfMovementIndicator', StrategyBasedIndicator.$);
    return EaseOfMovementIndicator;
}(StrategyBasedIndicator));
export { EaseOfMovementIndicator };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/EaseOfMovementIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { EaseOfMovementIndicatorStrategy } from "./EaseOfMovementIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var EaseOfMovementIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EaseOfMovementIndicator, _super);
    function EaseOfMovementIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EaseOfMovementIndicator.prototype.bc = function () {
        return new EaseOfMovementIndicator();
    };
    EaseOfMovementIndicator.prototype.get_y0 = function () {
        return new EaseOfMovementIndicatorStrategy();
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.prototype.get_zd = function () {
        return EaseOfMovementIndicator.$;
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.$t = markType(EaseOfMovementIndicator, 'EaseOfMovementIndicator', StrategyBasedIndicator.$);
    return EaseOfMovementIndicator;
}(StrategyBasedIndicator));
export { EaseOfMovementIndicator };
